package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`"``!````L!<``#0```!LI@``!Q``<#0`(``+
M`"@`'P`>``8````T````-````#0```!@`0``8`$```0````$`````P```)0!
M``"4`0``E`$```T````-````!`````$````#``!PR`$``,@!``#(`0``&```
M`!@````$````"````````'#@`0``X`$``.`!```8````&`````0````$````
M`0```````````````````$2:``!$F@``!0```````0`!````^)\``/B?`0#X
MGP$`Y`$``!@2```&```````!``(````<`@``'`(``!P"``!0`0``4`$```0`
M```$````!````*0!``"D`0``I`$``"`````@````!`````0````$````^`$`
M`/@!``#X`0``)````"0````$````!````%+E=&3XGP``^)\!`/B?`0`(````
M"`````0````!``````````````````````````````````````````0````O
M;&EB+VQD+G-O+C$`````!````!`````!````1TY5```````#`````@``````
M```````````@`@$!``4`````````````````````]@$`L@``````````````
M```````P(`(`!````!0````#````1TY5`!UYY(T;%_5-BT((M_$6A:*FX@?J
M`0```!P````!````Y@$```$```#Q`0```0```/L!```!````2@(```$```"L
M`P```0```,8#```,````<!0```T```!@6@``&0```/B?`0`;````!````!H`
M``#\GP$`'`````0````$````;`,```4```!\#0``!@```*P&```*````004`
M``L````0````-0``<(2=`0`5``````````,```!`H`$`$0```$@4```2````
M*````!,````(`````0``<`$````%``!P`@````8``'``````"@``<!P````1
M``!P;0```!(``'`>````$P``<",````>````"````/O__V\!```(_O__;Y@3
M``#___]O`P```/#__V^^$@``````````````````````````````````````
M````````````````````````````80```&T````````````````````K````
M```````````R```````````````H````3@````````!(````3P````X`````
M````5P```!D````#````+0````D````1````/0```#```````````````%@`
M```5````)P``````````````(@```!P````^```````````````6````(0``
M```````V`````````#0`````````1P```!0````2````)0````````!J````
M&@````````!&````50``````````````&````$D````Z````10``````````
M````8`````````!2`````````"```````````````&0````F````*0```"X`
M``!$````*@```````````````@````L```!`````9P```!L````0````-0``
M```````C````'P``````````````$P```!<`````````/P```!X```!"````
M)````#$````[`````````````````````````````````````````&8`````
M``````````````!H````````````````````40```&4````*````#0``````
M````````0P````0`````````````````````````7@```%H`````````````
M````````````70```#<````\`````````#,```!+````+P```!T`````````
M+```````````````7P```&P```!C````4````#D```!!````2@`````````X
M````4P``````````````8@```$T````````````````````/``````````@`
M`````````````&$````,````3`````````!I`````````%L`````````````
M`%D`````````````````````````5````%8`````````````````````````
M``````````!<````:P``````````````!0````````````````````<`````
M``````````````````````````8`````````````````````````````````
M````````````````````````<!0````````#``T`Y`,``'16```(````$@`.
M`*P$``!8-P``&````!(`#@`!`````0`````````3`/'_TP0```"@`0``````
M(0`5`*(#`````````````!$````Z!```9#\``%0````2``X`H`0``.!4``#,
M````$@`.`+T$``#<H0$``````!``&`#N`P``8%H````````2`!``Q`0``#0Z
M```L````$@`.`(H$``!@.@``A`$``!(`#@!]!```&$$``&0.```2``X`T00`
M``"@`0``````$0`5`(0#``"06@``!````!$`$0#>!````*`!```````0`!4`
M$@0``$@V```0`0``$@`.`!(````PH`$``````!$`%@#4`P``T%4``*0````2
M``X`E@0``""@`0`$````$0`5`.4$```0L@$``````!``&0!P!```Y#L``-`"
M```2``X`Z@0``-RA`0``````$``9`/0#``!L-0``5````!(`#@#6`@``L!0`
M`/P"```2``X`]@0``+`7````````$@`.`%4$``!P-P``Q`(``!(`#@`H!```
MN#\``&`!```2``X`HP,`````````````(0```&($``"T/@``L````!(`#@#^
M!```L!0````````0``X`!04``-RA`0``````$``9`/8#``!P%````````!(`
M#0#\`P``?$\``&0%```2``X`+0,``$!:````````$@```%0"```P6@``````
M`!(```"K`@``(%H````````2````"P(``!!:````````$@```'D#````6@``
M`````!(````1`@``\%D````````2````^`(``.!9````````$@```*0#````
M`````````!$```"C`@``T%D````````2````PP``````````````(````&H"
M``#`60```````!(```!)`P``L%D````````2````N@```*!9````````$@``
M`-T```"060```````!(```"I```````````````2````[````(!9````````
M$@```$(#``!P60```````!(```!X`@``8%D````````2````^@```%!9````
M````$@```)X```!`60```````!(```!<`@``,%D````````2````"P$``"!9
M````````$@```)`````060```````!(````[`P```%D````````2````.0(`
M`/!8````````$@```'T``````````````!(````:`P``X%@````````2````
MC0(``-!8````````$@```!<!``#`6````````!(````B`0``L%@````````2
M````-P$``*!8````````$@```"4"``"06````````!(```#)`@``@%@`````
M```2````6@,``'!8````````$@```&X```!@6````````!(```#"`@``4%@`
M```````2````0P$`````````````$0```/,"``!`6````````!(```!2`0``
M```````````B````(`,``#!8````````$@```&$!```@6````````!(```!]
M`0``$%@````````2````DP,```!8````````$@```'$!``#P5P```````!(`
M``!_`@``X%<````````2````,0(``-!7````````$@````@#``#`5P``````
M`!(```!C````L%<````````2````A`$``*!7````````$@```)8!``"05P``
M`````!(```#;`@``@%<````````2````I`$`````````````$0```%4```!P
M5P```````!(```"4`@``8%<````````2````L0$`````````````$0```'(#
M``!05P```````!(```!A`P``0%<````````2````2P```#!7````````$@``
M`#P````@5P```````!(````"`P``$%<````````2````+```````````````
M$@```+P!````5P```````!(```"T`P`````````````1````4P,``/!6````
M````$@```+0"``#@5@```````!(```!0````T%8````````2````FP(``,!6
M````````$@```)L#`````````````!$```!,!```L%8````````2````R@$`
M````````````(````"P"``"@5@```````!(```#D`@`````````````B````
MA@(``)!6````````$@```+L"``"`5@```````!(`````7T193D%-24-?3$E.
M2TE.1P!?7U),1%]-05``;&EB<&5R;"YS;RXU+C(X`&)O;W1?1'EN84QO861E
M<@!P97)L7V-O;G-T<G5C=`!P97)L7V9R964`<&5R;%]D97-T<G5C=`!P97)L
M7V%L;&]C`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L
M7W-Y<U]T97)M`'!E<FQ?<&%R<V4`4&5R;%]A=&9O<FM?;&]C:P!P97)L7W)U
M;@!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<W9?<V5T<'9N`%!E
M<FQ?879?9F5T8V@`4&5R;%]N97=84U]F;&%G<P!097)L7VUG7W-E=`!097)L
M7VYE=UA3`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?9V5T7W-V`%!,7VUE
M;6]R>5]W<F%P`%]?9VUO;E]S=&%R=%]?`%!E<FQ?9W9?9F5T8VAP=@!097)L
M7W-A9F5S>7-M86QL;V,`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P
M=@!03%]D;U]U;F1U;7``4$Q?=&AR7VME>0!097)L7V%V7W-H:69T`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L
M:6)P=&AR96%D+G-O+C``8VQO<V4`<'1H<F5A9%]G971S<&5C:69I8P!O<&5N
M-C0`<F5A9`!L<V5E:S8T`%]?97)R;F]?;&]C871I;VX`;&EB8RYS;RXV`&]P
M96YD:7(`7U]S=')N8W!Y7V-H:P!?7V9P<FEN=&9?8VAK`&%C8V5S<P!G971P
M:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E
M9&ER`'-T<F1U<`!S=')S='(`<W1R8VAR`%]?;&EB8U]S=&%R=%]M86EN`')E
M861L:6YK`%]?8WAA7V9I;F%L:7IE`&5X:70`7U]X<W1A=#8T`')M9&ER`%]?
M<F5G:7-T97)?871F;W)K`&UK9&ER`%]?;65M8W!Y7V-H:P!?7W-P<FEN=&9?
M8VAK`&UE;6-H<@!S=')T;VL`<F5A9&1I<C8T`&UE;6-P>0!S=')L96X`7U]S
M=&%C:U]C:&M?9F%I;`!G971U:60`7U]L>'-T870V-`!?24]?<W1D:6Y?=7-E
M9`!R96%L;&]C`'-T9&5R<@!?7V5N=FER;VX`;&0N<V\N,0!?7W-T86-K7V-H
M:U]G=6%R9`!L:6)C<GEP="YS;RXQ`%]?;&EB8U]C<W5?:6YI=`!?7VQI8F-?
M8W-U7V9I;FD`>'-?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`'!A<E]S971U<%]L:6)P871H`&=E=%]U<V5R;F%M
M95]F<F]M7V=E='!W=6ED`'!A<E]F:6YD<')O9P!P87)?96YV7V-L96%N`'!A
M<E]I;FET7V5N=@!P87)?;6MT;7!D:7(`<&%R7V1I<FYA;64`;7E?<&%R7W!L
M`'!A<E]C;&5A;G5P`'!A<E]C=7)R96YT7V5X96,`7V5D871A`'!A<E]B87-E
M;F%M90!?7V1A=&%?<W1A<G0`7V9D871A`%]E;F0`7U]B<W-?<W1A<G0`7U]S
M=&%R=`!?9G1E>'0`7V9B<W,`1TQ)0D-?,BXT`$=,24)#7S(N,@!'3$E"0U\R
M+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(````````!``$``0`!``(``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`"``$`
M`0`!``$``0`)``(``@`$``,`!``#``(``@````D``P````````````(``@``
M````"0```````@`$`````@`"``````````@``@`"`````@````(````)````
M`@`"`````@`(``<``````````@```````@````(`!@```````@``````!0`"
M``(``@`"``(``@````0``P`"``(``0`!`*P#```0````(````!1I:0T```4`
M"P4````````!``(`^P$``!`````P````$FEI#0``"``5!0``$````!!I:0T`
M``0`'P4````````!``4`2@(``!``````````=!EI"0``"0`I!0``$````'(9
M:0D```<`-04``!`````4:6D-```&``L%```0````$FEI#0```P`5!0``$```
M`!!I:0T```(`'P4``````````````````/B?`0`#````_)\!``,````@H`$`
M`P```-BA`0`#`````@`</,`+G"<AX)D#X/^])Q``O*\<`+^O&(&"CP0`0!``
M````&(&9CPGX(`,`````'`"_CP@`X`,@`+TG``````(`'#R`"YPG(>"9`[#_
MO2<(@9F/-`"PKQ@`O*],`+^O2`"UKT0`M*]``+.O/`"RKS@`L:]X@9"/)`"E
MKR0`I2<@`*:O(`"F)U``I*]0`*0G```"CBP`HJ\)^"`#`````!@`O(_D@(:/
M6("9C[B`A(\C$!$$)2C``!@`O(],@8*/``!"D&@`0!`\@9F/6(&1CY2`F8\)
M^"`#```DCA@`O(]F`T.0```DCI2`F8\"`&,T"?@@`V8#0Z``0`,\4`"DCV8#
M19`8`+R/!0"$)`$`I30K&(,`?@!@$&8#1:`L@9F/"?@@`X`@!``D`*6/&`"\
MCU``IH\``*.,7("$CRB`B(\``$.L)("#CP``AXP"`,0H]+$"K<Q=8R0(`$>L
M!``')`0`0ZPD@(./T%UC)`P`0ZPH@(./"@"`%/BQ9ZR`0`8`!`"C)!``1"0A
M0*@```!EC`0`A"0$`&,D_/\#%?S_A:PH@)&/@!@&`"2`A8\#`,8D(1A#`,R`
MF8\0`*"O)3A```"R)([`-:4D"?@@`PP`8*P8`+R/-0!`$"680`!0@9F/*`"T
M)PGX(`,`LB2.)2B``A@`O(\D@)*/)("$C_PK4B8ER$`"8041!%Q;A"0M`$`0
M&`"\CV2!F8\)^"`#`+(DCA@`O(_8@)F/"?@@`P`````E$&`"+`"DCP```XX\
M`(,4&`"\CTP`OX](`+6/1`"TCT``LX\\`+*/.`"QCS0`L(\(`.`#4`"])PGX
M(`,`````&`"\CRB`@X\J`$`0`+)BK&B!F8]8@9&/"?@@`R4@0``8`+R/E("9
MCPGX(`,``"2.&`"\CXK_`!`1!T"@L("9CPGX(`,`LB2.&`"\C\?_`!`EF$``
M*("5C_RQI(X%`(`08("9CV8/$00`````S?\`$!@`O(\D@(2/)2B``B7(0`(F
M!1$$^%J$)!@`O(\E($``Q/]`$/RQHJ[R_P`08("9CR2`A(\0@86/]("9CPGX
M(`,$780D%(&9CPGX(`,!``0D8(&9CPGX(`,``````````"4`X`,!`!$$````
M``(`'#QT")PG(>"?`R7X```8@(2/``"ECP0`IB?X_P$D).BA`^#_O2<<@(>/
M(("(CQ``J*\4`**O&`"]KP"!F8\)^"`#`````/__`!````````````(`'#P@
M")PG(>"9`RB`A(]D@(*/-*"$)`4`1!"4@9F/`P`@$P`````(`"`#``````@`
MX`,``````@`</.@'G"<AX)D#*("$CV2`A8\TH(0D(RBD`(,H!0#"%P4`(2A%
M`$,H!0`%`*`0I("9CP,`(!,`````"``@`P`````(`.`#``````(`'#R<!YPG
M(>"9`^#_O2<8`+"O*("0CQ``O*\<`+^OX*$"D@T`0!2<@8*/!0!`$&B`@H^<
M@9F/"?@@`P``1(P0`+R/)("9CQ`8.2?+_Q$$``````$``B3@H0*B'`"_CQ@`
ML(\(`.`#(`"])P(`'#PP!YPG(>"9`R2`F8](&#DGS/\`$````````````@`<
M/!`'G"<AX)D#4/V])WB!BH\X`(@D&`"B)Q``O*]X`(TDK`*_K_\`##RH`K&O
M)3!``*0"L*\``$.-G`*CKP0`!8T(``@E$`#&)/3_P*S\_\"L`AH%`/C_!XT"
M7@4``$X%``#_8S"@.`=\`"H%`"48:P`"/"<`)1AI`"0HK`#P_\>L)1AE`.W_
MJ!7X_\.L``)+)&@`28P(`$(D?`!`K#@`0XP\`$6,9`!(C`@`1XPF2",!#`!&
MC"9`!0'X_T.,_/]%C"8XZ0`F,,@`)AAG`"8HI@!`*`4`PC<#`$`8`P`E**8`
M)1AE`.K_2Q1X`$.L``"(C():`CP$`(:,"`"'C)EY0B0,`(6,PFX(`$`9!@`8
M`+B/@G`'`!``B8R`+P4`(`",C"48;0`8`(N,@&\'``0`@*PE**X`#`"`K"5P
MI0$@`*6/(<`"`Q0`@*Q`>0@`'`"`K"$HH@`F:"X!(<`,`R5XXP$D:*@!)A@K
M`2$HJP`A>/@!)FBI`2089P""P`@`(2BM`"@`K8\F&&L`@#<&`"$8XP&`?P@`
M)3#8`"7`Y@'"A@,`0,D#`"%HH@$F>-@!)3`P`R%HJ0$D>.,!(2BF`"9X[@&"
MB`,`@#<#`"$8KP$P`*V/PH8%`$#)!0`E,-$`)7@P`R%HH@$A&&\`)G@&`R%H
MK@$D>.4!)GCX`8*(!0"`=P4`(2BO`3@`KX_"A@,`0,D#`"5PT0$E:#`#(7CB
M`2$HK0`F:,X`(7CX`23`HP$FP`8#@H@#`(!O`P`A&/@!0`"OC\*&!0!`R04`
M)6BQ`27`,`,A>.(!(1AX`";`S0$A,.8!@H@%`(!_!0`DP`4#)L`.`R$HV``E
M,/$!2`"OC\*&`P!`R0,`(7CB`27`,`,A*+@`)L"F`2%P[@&"B`,`@'\#`"3`
M`P,FP`T#(1C8`25P\0%0`*^/PH8%`$#)!0`A>.(!)<`P`R$8>``FP,X`(6CM
M`8*(!0"`?P4`),`%`R;`!@,A*+@!)6CQ`5@`KX_"A@,`0,D#`"%XX@$EP#`#
M(2BX`";`S0$A,.8!@H@#`(!_`P`DP`,#)L`.`R$8V``E,/$!8`"OC\*&!0!`
MR04`(7CB`27`,`,A&'@`)L"F`2%P[@&"B`4`@'\%`"3`!0,FP`T#(2C8`25P
M\0%H`*^/PH8#`$#)`P`A>.(!)<`P`R$HN``FP,X`(6CM`8*(`P"`?P,`),`#
M`R;`!@,A&+@!)6CQ`7``KX_"A@4`0,D%`"%XX@$EP#`#(1AX`";`S0$A,.8!
M@H@%`(!_!0`DP`4#)L`.`R$HV``E,/$!>`"OC\*&`P!`R0,`(7CB`27`,`,A
M*+@`)L"F`2%P[@&"B`,`@'\#`"3``P,FP`T#(1C8`25P\0&``*^/PH8%`$#)
M!0`A>.(!)<`P`R$8>``FP,X`(6CM`8*(!0"`?P4`),`%`R;`!@,A*+@!)6CQ
M`8@`KX_"A@,`0,D#`"%XX@$EP#`#(2BX`";`S0$A,.8!@H@#`(!_`P`DP`,#
M)L`.`R$8V``E,/$!D`"OC\*&!0!`R04`(7CB`27`,`,A&'@`)L"F`2%P[@&"
MB`4`@'\%`"3`!0,FP`T#(2C8`25P\0&8`*^/PH8#`$#)`P`A>.(!)<`P`R$H
MN``FP,X`(6CM`21X`P,F>.8!(6BO`:``KX_"A@4`0,D%`(#'`P""&`,`(7CB
M`27``P,E&#`#(1BC`29HV`$A>.8!)#"E`8)H!0"`+P4`)C#.`"5HK0"H`*6/
MPH8#`$#)`P`A>.8!(2BB`"4P,`,A>.8!)C`-`X*``P`A<*X`)"C#`(`?`P`F
M*+@`(7#%`24H<`"P`*./PLX/`$`Q#P`A&&(`)3#9`"%PQ@$F,*4!(1AX`"0P
MSP`F,,T`(1AF`+@`IH_9;@(\@L@/`*'K0C2`?P\`(3#"`"5X^0$A,,T`)FBO
M`"9HK@$A,,T`P`"MC\*&#@!`P0X`@L@.`(!W#@`EP!`#(6BB`2$8>``E<-D!
M(2BE`29H[@$F:*,!PH8#`(+(`P!`P0,`(2BM`(!O`P#(`*./)<`0`R$PV``A
M&&(`)6BY`2$8;P`F>,T!)GCF`<*&!@""R`8`0,$&`"$8;P"`?P8`T`"FCR7`
M$`,A*+@`(3#"`"5X^0$A,,X`)G"O`29PQ0'"A@4`@L@%`$#!!0`A,,X`@'<%
M`-@`I8\EP!`#(1AX`"$HH@`E<-D!(2BM`"9H[@$F:*,!PH8#`(+(`P!`P0,`
M(2BM`(!O`P#@`*./)<`0`R$PV``A&&(`)6BY`2$8;P`F>,T!)GCF`<*&!@""
MR`8`0,$&`"$8;P"`?P8`Z`"FCR7`$`,A*+@`(3#"`"5X^0$A,,X`)G"O`29P
MQ0'"A@4`@L@%`$#!!0`A,,X`@'<%`/``I8\EP!`#(1AX`"$HH@`E<-D!(2BM
M`"9H[@$F:*,!PH8#`(+(`P!`P0,`(2BM`(!O`P#X`*./)<`0`R$PV``A&&(`
M)6BY`2$8;P`F>,T!)GCF`<*&!@""R`8`0,$&`"$8;P"`?P8```&FCR7`$`,A
M*+@`(3#"`"5X^0$A,,X`)G"O`29PQ0'"A@4`@L@%`$#!!0`A,,X`@'<%``@!
MI8\EP!`#(1AX`"$HH@`E<-D!(2BM`"9H[@$F:*,!PH8#`(+(`P!`P0,`(2BM
M`(!O`P`0`:./)<`0`R$PV``A&&(`)6BY`2$8;P`F>,T!)GCF`<*&!@""R`8`
M0,$&`"$8;P"`?P8`&`&FCR7`$`,A*+@`(3#"`"5X^0$A,,X`)G"O`29PQ0'"
MA@4`@L@%`$#!!0`A,,X`@'<%`"`!I8\EP!`#(1AX`"$HH@`E<-D!(2BM`"9H
M[@$F:*,!PH8#`(+(`P!`P0,`(2BM`(!O`P`H`:./)<`0`R$PV``A&&(`)6BY
M`2$8;P`F>,T!)GCF`<*&!@""R`8`0,$&`"$8;P"`?P8`,`&FCR7`$`,A*+@`
M(3#"`"5X^0$A,,X`)G"O`29PQ0'"A@4`@L@%`$#!!0`A,,X`@'<%`#@!I8\E
MP!`#(1AX`"$HH@`E<-D!(2BM`"9H[@$F:*,!PH8#`(+(`P!`P0,`(2BM`(!O
M`P!``:./)<`0`R$PV``A&&(`)6BY`2$8;P`F>,T!)GCF`<*&!@!`P08`(1AO
M`$@!KX\EP!`#@L@&`(`W!@`A*+@`(7CB`24PV0#"A@4`0,$%`"%X[@$F<*8!
M)G#%`27`$`,A>.X!4`&NCR$8>`""R`4`@"\%`,*&`P!`P0,`(7#"`24HN0`E
MP!`#(7#-`29HQ0`A>/@!)FBC`2%PS0%8`:V/&X\"/,+.#P""@`,`0,$/`(`?
M`P#<O$(T)1AP`"7`&0,A:*(!(7#8`27`HP`A:*8!),`/`R0PHP`EP`8#(6BX
M`6`!N(_"A@X`0,D.`(*(#P"`-P\`(<`"`R4PT0`E>#`#(6BO`25X9@`DR&8`
M(<`%`R1X[@$E>/D!@H@.`(`O#@`A</@!:`&XC\*&#0!`R0T`)2BQ`"5X,`,A
MP`(#(7#/`25XQ0`DR,4`(<`#`R1X[0$E>/D!@H@-`(`?#0`A:/@!<`&XC\*&
M#@!`R0X`)1AQ`"5X,`,AP`(#(6BO`25XHP`DR*,`(<`&`R1X[@$E>/D!@H@.
M`(`W#@`A</@!>`&XC\*&#0!`R0T`)3#1`"5X,`,AP`(#(7#/`25X9@`DR&8`
M(<`%`R1X[0$E>/D!@H@-`(`O#0`A:/@!@`&XC\*&#@!`R0X`)2BQ`"5X,`,A
MP`(#(6BO`25XQ0`DR,4`(<`#`R1X[@$E>/D!@H@.`(`?#@`A</@!B`&XC\*&
M#0!`R0T`)1AQ`"5X,`,AP`(#(7#/`25XHP`DR*,`(<`&`R1X[0$E>/D!@H@-
M`(`W#0`A:/@!D`&XC\*&#@!`R0X`)3#1`"5X,`,AP`(#(6BO`25X9@`DR&8`
M(<`%`R1X[@$E>/D!@H@.`(`O#@`A</@!F`&XC\*&#0!`R0T`)2BQ`"5X,`,A
MP`(#(7#/`25XQ0`DR,4`(<`#`R1X[0$E>/D!@H@-`(`?#0`A:/@!H`&XC\*&
M#@!`R0X`)1AQ`"5X,`,AP`(#(6BO`25XHP`DR*,`(<`&`R1X[@$E>/D!@H@.
M`(`W#@`A</@!J`&XC\*&#0!`R0T`)3#1`"5X,`,AP`(#(7#/`25X9@`DR&8`
M(<`%`R1X[0$E>/D!@H@-`(`O#0`A:/@!L`&XC\*&#@!`R0X`)2BQ`"5X,`,A
MP`(#(6BO`25XQ0`DR,4`(<`#`R1X[@$E>/D!@H@.`(`?#@`A</@!N`&XC\*&
M#0!`R0T`)1AQ`"5X,`,AP`(#(7#/`25XHP`DR*,`(<`&`R1X[0$E>/D!@H@-
M`(`W#0`A:/@!P`&XC\*&#@!`R0X`)3#1`"5X,`,AP`(#(6BO`25X9@`DR&8`
M(<`%`R1X[@$E>/D!@H@.`(`O#@`A</@!R`&XC\*&#0!`R0T`)2BQ`"5X,`,A
MP`(#(7#/`25XQ0`DR,4`(<`#`R1X[0$E>/D!@H@-`(`?#0`A:/@!T`&XC\*&
M#@!`R0X`)1AQ`"5X,`,AP`(#(6BO`25XHP`DR*,`(<`&`R1X[@$E>/D!@H@.
M`(`W#@`A</@!V`&XC\*&#0!`R0T`)3#1`"5X,`,AP`(#(7#/`25X9@`DR&8`
M(<`%`R1X[0$E>/D!@H@-`(`O#0`A:/@!X`&XC\*&#@!`R0X`)2BQ`"5X,`,A
MP`(#(6BO`25XQ0`DR,4`(<`#`R1X[@$E>/D!@H@.`(`?#@`A</@!Z`&OC\*&
M#0!`R0T`)1AQ`"7`,`,A>.(!(7#8`27`HP`DR*,`(3#F`23`#0,EP!D#(<`&
M`_`!IH^"@`T`@&\-`,+.#@!`>0X`)6BP`2$0P@`E>/D!)3!M`"'`#P,A*$4`
M)'AM`"0PS@`E,,\`(3#%`/@!I8]BR@(\@L@.`-;!0C2`=PX`(2BB`"5PV0'"
MAA@`0'D8`"$HHP`F&*X!)7CP`288>``A,,\`(2BC```"HX_"A@8`@L@8`$!Y
M!@"`QQ@`(1AB`"7`&0,E>/`!(2BO`"$8;0`F>-@!)GCF`8+(!@`A&&\`@'\&
M``@"IH_"A@4`)7CY`2$PP@!`:04`(3#.`"9P#P,E:+`!)G#%`2$8;0""R`4`
M(3#.`(!W!0`0`J6/PH8#`$!I`P`A**(`)7#9`25HL`$A,,T`(2BX`"9H[@$F
M:*,!@L@#`"$HK0"`;P,`&`*CC\*&!@`E:+D!(1AB`(+(!@`A&&\`)GC-`29X
MY@%`P08`(1AO`(!_!@`@`J:/)<`0`R$HN``A,,(`)7CY`2$PS@`F<*\!)G#%
M`<*&!0""R`4`0,$%`"$PS@"`=P4`*`*ECR7`$`,A&'@`(2BB`"5PV0$A**T`
M)FCN`29HHP'"A@,`@L@#`$#!`P`A**T`@&\#`#`"HX\EP!`#(3#8`"$88@`E
M:+D!(1AO`"9XS0$F>.8!PH8&`(+(!@!`P08`(1AO`(!_!@`X`J:/)<`0`R$H
MN``A,,(`)7CY`2$PS@`F<*\!)G#%`<*&!0""R`4`0,$%`"$PS@"`=P4`0`*E
MCR7`$`,A&'@`(2BB`"5PV0$A**T`)FCN`29HHP'"A@,`@L@#`$#!`P`A**T`
M@&\#`$@"HX\EP!`#(3#8`"$88@`E:+D!(1AO`"9XS0$F>.8!PH8&`(+(!@!`
MP08`(1AO`(!_!@!0`J:/)<`0`R$HN``A,,(`)7CY`2$PS@`F<*\!)G#%`<*&
M!0""R`4`0,$%`"$PS@"`=P4`6`*ECR7`$`,A&'@`(2BB`"5PV0$A**T`)FCN
M`<*&`P`F:*,!0,$#`(+(`P`A**T`@&\#`&`"HX\EP!`#(3#8`"$88@`E:+D!
MPH8&`$#!!@`A&&\`)GC-`27`$`,F>.8!(2BX`(+(!@`A&&\`@'\&`&@"IH_"
MA@4`0,$%`"$PP@`E>/D!)<`0`R$8>``A,,X`)L"O`2;`!0."R`4`(3#8`(#'
M!0!P`J6/PH8#`$!Q`P`A**(`)<`9`R5PT`$A**T`)FCX`2$PS@`F:*,!@L@#
M`"$HK0"`;P,`>`*CC\*&!@!`<08`(1AB`"5PT`$A**X`)7"Y`29H#@,A&&\`
M)FBF`8+(!@`A&&T`@&\&`(`"IH_"A@4`0'D%`"$PP@`E>/`!(1AO`"5XN0$F
M:,\!(3#8`"9HI0'"A@,`(3#-`(@"K8]`P0,`@L@%`"7`$`.`+P4`(<#8`"%H
MH@$E*+D`(6BN`4`Q&``F<.4!PH88`"9PPP&"R`,`(6BN`8!W`P`E&-``D`*F
MCR%HHP$A,,(`)1#9`288H@`A,,\`)AAX`,+.#0!`<0T`(3##`()X&`"`'Q@`
M)7#9`2$PS@`E&&\`(4AI`"$02P`A0,@`$`")K"$X[0`8`(*L(2BL````B*P(
M`(>L(`"%K"0`@*R<`J./``!"C04`8A2L`K^/J`*QCZ0"L(\(`.`#L`*])V"!
MF8\)^"`#``````(`'#PT])PG(>"9`\C_O2<0`+RO-`"_KS``MJ\L`+6O*`"T
MKR0`LZ\@`+*O'`"QKT0`@!`8`+"OG(""CP``58Q``*`2````````@H`$`$`0
M)9```#T``R0A`$,4````````L(X3```2/0`6)"6@H``EF(``)8B@`J"`F8\E
M(``")3!``@GX(`,E*&`"(1@2`@0`0!00`+R/``!B@!D`5A``````!``Q)@``
M,([S_P`6H("9CS0`OX\E$``",`"VCRP`M8\H`+2/)`"SCR``LH\<`+&/&`"P
MCP@`X`,X`+TG)9"```$`4B8``$*"`P!`$`````#[_T,4`````-C_`!`CD$0"
M(X@U`@$`4B:#B!$`(8`2`@``D:XT`+^/)1```C``MH\L`+6/*`"TCR0`LX\@
M`+*/'`"QCQ@`L(\(`.`#.`"])S0`OX\E@```,`"VCR40``(L`+6/*`"TCR0`
MLX\@`+*/'`"QCQ@`L(\(`.`#.`"])P(`'#S`\IPG(>"9`\C_O2<L`+.O,`"T
MKQ@`M"<H`+*O)`"QKR6(@``@`+"O$`"\KS0`OZ]X@9./)("0CYR`DH\``&*.
M_"L0)AP`HJ\E*(`")<@``HW_$00E("`"$@!`$!``O(\8`*./``!"CH`8`P`A
M$$,`!`!#C/3_8!```$.L!`!")`0`0XS]_V`4``!#K"4H@`(ER``"?/\1!"4@
M(`+P_T`4$`"\CQP`HX\``&*."`!B%#0`OX\P`+2/+`"SCR@`LH\D`+&/(`"P
MCP@`X`,X`+TG8(&9CPGX(`,``````@`</.#QG"<AX)D#N/^])ST``B0H`+&O
M,`"SKR68@``D`+"O)8"@`!``O*]$`+^O0`"WKSP`MJ\X`+6O-`"TKRP`LJ]X
M@9&/``"C@```)(X<`*2O`@!B%`2!F8\!`+`D"?@@`R4@``(8`*4G$`"\CR4@
M8`(D@)F/_"LY)TO_$00EH$``$`"\CUD`0!`ED$``!(&9CPGX(`,E($``*Q!4
M`$<`0!`0`+R/&`"RCYR`E8^`L!(```!B@GX`0!`]``,D?`!#$``````#```0
M)2!@`@4`0Q```````0"$)```@H#[_T`4`````",@DP```+*.`@"4)B2!F8\A
M((0""?@@`R&05@(0`+R/:`!`$```0JX8`*./`0!D)@``HHX``&6"@!@#`"$0
M0P```$.,#0"@$```9:`]``(D"@"B$``````#```0/0`%)`8`11```````0"$
M)/__@H`!`&,D^O]`%```8J`]``0D`0!B)```9*`!`!`F__\#@@$`0B3\_V`4
M__]#H"40```<`*2/```CCDT`@Q1$`+^/0`"WCSP`MH\X`+6/-`"TCS``LX\L
M`+*/*`"QCR0`L(\(`.`#2`"])P$`$";__P*"`0!2)NW_0!#__T*B`0`0)O__
M`H(!`%(F]_]`%/__0J+G_P`0)1```)R`E8\``+>.``#BCB\`0!`E$.`"`@``
M$"48```E&$`"!`!")```1(S\_X`4`0!R)`,`8R2`(`,`*(""C_"Q0XP6`&`4
M*(&9CR2!F8\!``,D"?@@`_"Q0ZP8`$`0$`"\CXB!F8^`L!(`)2C@`B4PP`()
M^"`#)2!``!``O(\E&$````"BK@$`0B:`$`(`(1AB````8*R+_P`0&`"RKR4H
M@``E(.`""?@@`X"P$@`0`+R/)1A``//_0!0``**NMO\`$/__`B2-_P`0)2``
M``@`!"39_P`0)9```&"!F8\)^"`#``````(`'#P,[YPG(>"9`PC_O2?8`+*O
M&`"\K_0`OZ_P`+ZO[`"WK^@`MJ_D`+6OX`"TK]P`LZ_4`+&OT`"PKWB!DH\`
M`$*.S`"BKP0`@!````````""@!``0!0EB(``S`"CCP``0HYM`&(4]`"_C_``
MOH_L`+>/Z`"VC^0`M8_@`+2/W`"SC]@`LH_4`+&/T`"PCP@`X`/X`+TGA("9
MCPGX(`,`````&`"\C^S_0!`EF$``)("4CR@`MR<D@)6/)("6CR2`@H^46I0F
MG%JU)B0QUB8D`**OK("9CPGX(`,E(&`"00!`$!@`O(^@@9F/$P!0)"4H@`()
M^"`#)2```O7_0!`8`+R/)`"BCR4@``*@@9F/"?@@`YA:123N_T`0&`"\CP2!
MF8\)^"`#)2`@`B4@``(8`+R/!(&9CPGX(`,E\$``&`"\CR$0P@,D@9F/"?@@
M`P(`1"3__P8D&`"\CP$`!20E($``%`"PKR4XH`(0`+&O@("9CPGX(`,E\$``
M`P`$)!@`O(\E,.`"F("9CPGX(`,E*,`#__\$)`8`1!`8`+R/0`"BCP!`!"0`
M\$(P%P!$$"7(P`)4@9F/"?@@`R4@P`,8`+R/A(&9CPGX(`,E(,`#&`"\CZR`
MF8\)^"`#)2!@`L'_0!08`+R/B("9CPGX(`,E(&`"&`"\CVR!F8\)^"`#)2`@
M`I7_`!`8`+R/?/\1!"4@P`/K_P`0&`"\CV"!F8\)^"`#``````(`'#SD[)PG
M(>"9`S#_O2>0@)F/&`"F)\0`L*\0`+ROR`"QKR6(@`#,`+^O`P`$)'B!D(\E
M*"`"```"CKP`HJ\)^"`#``````\`0!00`+R/,`"CCP!`!"0`\&,P`P!D$`"@
M!#0)`&04`````,2`F8\"``4D"?@@`R4@(`(0`+R/`@``$`$`0BPE$```O`"D
MCP```XX%`(,4S`"_C\@`L8_$`+"/"`#@`]``O2=@@9F/"?@@`P`````"`!P\
M+.R<)R'@F0/`[[TG2(&9C_\/!B0L$+*O$`"\KS00M*\EH*``,!"SKR68@``D
M$+"O'`"P)SP0OZ\X$+6O)2@``B@0L:]X@9*/)("$CP``0HZD6H0D'!"BKPGX
M(`,`````.@!`&!``O(___U$D6(&$CR`0HR<A&'$`_.]C@"``8!0``)6,)@`@
M$MR`F8\O``4D)3`@`@GX(`,E(``"(`!`$!``O(^4@)F/"?@@`R4@H`(E."`"
M$`"\CR4P``(E*&`"M("9CPGX(`,E($``$`"\CQP0HX\``$*.'P!B%#P0OX\X
M$+6/-!"TCS`0LX\L$+*/*!"QCR00L(\(`.`#0!"])]R`F8\EB$``+P`%)"4P
M(`()^"`#)2```N+_0!00`+R/E("9CPGX(`,E(*`")3"``A``O(\E*&`"1(&9
MCPGX(`,E($``XO\`$!``O(]8@8*/\_\`$```58Q@@9F/"?@@`P`````"`!P\
MQ.J<)R'@F0/@_[TG6(&"CY2`F8\<`+^O$`"\KPGX(`,``$2,$`"\CR4@0``<
M`+^/(`"])RR`AX\D@(6/<(&&C_"`F8\TFN<D"``@`[1:I20"`!P\<.J<)R'@
MF0/8_[TGE("9CR``L*\D`+^O&`"\KUB!D(\)^"`#```$CA@`O(\P@)F/W?\1
M!"4@0``8`+R/E("9CPGX(`,```2.&`"\CR4@0``4`*"O)("'CR2`A8_(@)F/
MR%WG)#2`AH_06J4D"?@@`Q``IZ\D`+^/(`"PCP@`X`,H`+TG`@`</.CIG"<A
MX)D#P-^])S"!F8\T(+&O/""_KQ@`O*\X(+*O*!"R)S`@L*\D`+`G>(&1CP``
M(HXL(**O"?@@`P`````!$`8D&`"\CP$`!200`**O)2```B2`@H\D@(>/@("9
MC_1:0B3H6N<D"?@@`Q0`HJ\`$`8D&`"\CR4H0`)(@9F/"?@@`R4@``(;`$`$
M&`"\CR2!F8\!`$0D"?@@`R6`0``8`+R/"@!`$"480`!\@9F/)3```B4H0`()
M^"`#)2!``"&`4``8`+R/)1A``````*(L(*2/)1!@````(XX(`(,4/""_CS@@
MLH\T(+&/,""PCP@`X`-`(+TG]?\`$"48``!@@9F/"?@@`P`````"`!P\V.B<
M)R'@F0,X@)F/M_\`$``````"`!P\P.B<)R'@F0/X[KTG>(&"CR2`F8\@`+RO
M!!&_K_PK.2?L$+.O)9B@`.00L:\EB(``X!"PKS0`I2<`$;ZO_!"WK_@0MJ_T
M$+6O\!"TK^@0LJ\L`**O)("$CP``0HSX6H0DW!"BKPC]$00`````+P`%)"``
MO(\E("`"#(&9CPGX(`,E@$``&0!`$"``O(\D@(2/)2@@`B2`F8]0+CDGC_T1
M!`1;A"0E$"`"(`"\CRP`HX_<$*2/``!CC'X`@Q0$$;^/`!&^C_P0MX_X$+:/
M]!"UC_`0M(_L$+./Z!"RC^00L8_@$+"/"`#@`P@1O2<$@9F/)("2CPGX(`,E
M("`")2!@`B``O(\46T4FP("9CPGX(`,EH$``(`"\C]S_0!`EN$``)("6CR2`
MDX\``.*")("5CY1:UB9!`$`0(%MS)@8``!*@@9F/)2C@`@GX(`,E(``",`!`
M$"``O(\$@9F/"?@@`R4@X`(O``,D(2#B`B``O(___X2`#`"#%"4H0`#^_T(D
M`0`$)"$8X@(C()<`+P`&)"$H@P`!`&"@__]C)`$`8H#[_T80``````$`@B8A
M*$4``!"E*+7_H!"`@)F/W`"^)QA;IR88`+&O`!`&)!0`LZ\!``4D$`"WKPGX
M(`,E(,`#.`"F)R``O(\#``0DF("9CPGX(`,E*,`#!@!`%"``O(]0`**/`(`#
M-`#P0C`5`$,0Q("9C\"`F8\46T4F"?@@`R4@```@`+R/F/]`$"6X0````.*"
MP?]`%``````:```2H(&9CR4HP`()^"`#)2```O#_0!`@`+R/);C``M+_`!`!
M``4D`0`%)`GX(`,E(,`#Z/]`%"``O(\D@(2/)2C``R2`F8]0+CDG%/T1!`1;
MA"0@`+R/@(&9CPGX(`,E(,`#@O\`$"``O(\!``4DOO\`$"6XP`)@@9F/"?@@
M`P```````(.`!P!@$"40@``!`(0D+P!C.`H0@P```(.`_/]@%`$`A"0(`.`#
M``````(`'#S0Y9PG(>"9`]C_O2<0`+RO)`"_KR``L:\C`(`0'`"PKP``@H`@
M`$`0)8"```2!F8\)^"`#`````/__0B0A$`("*Q@"`BD`8!`0`+R/``!$@"\`
M`R0<`(,4``````0``!`O``0D``!#@!<`9!0`````__]")/O_`A8```````!#
M@"\``B0[`&(0@(&9CR2`A(\D`+^/(`"QCQP`L(\@6X0D"``@`R@`O2<D@(2/
M@(&9CY1:A"0D`+^/(`"QCQP`L(\(`"`#*`"])P0``!`O``0D``!#@`<`9!``
M````__]")"L8`@+Z_V`4`````./_`A(`````!```$"\`!"0``$.`!0!D%```
M``#__T(D*Q@"`OK_8!0`````(Q!0``(`0R0!$&,L#0!@$"B`D8\`$`<DT("9
MCP$`1B0E*``""?@@`_"A)";PH2(F)`"_CR``L8\<`+"/"`#@`R@`O2<D`+^/
M)1```"``L8\<`+"/"`#@`R@`O2<D@(2/SO\`$)1:A"0"`!P\3.2<)R'@F0.8
M_[TG+(""CR``HR=4`+.O$)I")!``O*]D`+^O(`!%)&``MJ]<`+6O6`"TKU``
MLJ],`+&O2`"PKWB!DX\``&2.1`"DKP``2(P0`$(D$`!C)/#_:*ST_T>,^/]&
MC/S_1(ST_V>L^/]FK/;_113\_V2L)("0CQP`LB<D@(2/``!"E'`M$"8D@)2/
M)%N$)"2`E8\ER``".OP1!```8J0ER``"$`"\CR2`A(\D@):/)("1CS/\$00P
M6X0D)<@``A``O(\D@(2/+OP1!#A;A"0ER``"$`"\CR2`A(\I_!$$1%N$)"7(
M``(F_!$$3%N$)B7(``(0`+R/)("$CR'\$01<6X0D)<@``A[\$03X6J0F)<@`
M`AO\$01H6\0F)<@``AC\$01T6R0F)<@``A``O(\D@(2/$_P1!(!;A"0ER``"
M$`"\CR2`A(\._!$$!%N$)"4H0`(0`+R/)("0CR2`A(_\*Q`F)<@``JG[$02,
M6X0D-`!`$!``O(]T6R0F)("1CU`N,28ER"`"-OP1!"4H0``0`+R/)("$CR4H
M0`(ER``"F_L1!*!;A"0'`$`0$`"\CR2`A(\E*$``)<@@`BG\$02T6X0D$`"\
MCR2`A(\E*$`")<@``H[[$03`6X0D'`!`$!``O(_X6J0F)<@@`AW\$00E*$``
M$`"\CR2`A8],6X0F)<@@`A?\$03P6Z4D1`"CCP``8HXI`&(4$`"\CV0`OX]@
M`+:/7`"UCU@`M(]4`+./4`"RCTP`L8](`+"/"`#@`V@`O2<D@)&/TO\`$%`N
M,28D@(2/)2A``B7(``)L^Q$$T%N$)`<`0!`0`+R/:%O$)B7((`+[^Q$$)2A`
M`-[_`!`0`+R/)("%CPH`!B2@@)F/,0"D)PGX(`/D6Z4DUO]`%!``O(\[`*4G
M)<@@`NW[$01H6\0FT/\`$!``O(]@@9F/"?@@`P`````"`!P\?.&<)R'@F0/0
M_[TG__\#)"@`L:\D`+"O$`"\KRP`OZ]X@9"/*("1CP``!(X0H"*.'`"DKPD`
M0Q`D@(2/'`"DCP```XX6`(,4+`"_CR@`L8\D`+"/"`#@`S``O2<8`*4G)("9
MC_PK.2<V^Q$$:%N$)`@`0!`0`+R/``!"@`4`0!``````,`!"."L0`@#K_P`0
M$*`BKB40``#H_P`0$*`BKF"!F8\)^"`#``````(`'#S,X)PG(>"9`^#_O2=<
M@9F/$`"\KQP`OZ\)^"`#`````!``O(^0@9F/"?@@`R4@0``$`$`0'`"_CP``
M0HP(`.`#(`"])R40```(`.`#(`"])P(`'#QXX)PG(>"9`[C_O2<D@)F/*`"E
M)S0`L:_\*SDG(`"\KSP`LZ\EF(``.`"RKT0`OZ]``+2O,`"PKWB!D8\D@)*/
M```BCO1;1"8L`**O_/H1!``````%`$`0(`"\CR6`0````$*`$@!`%*2!F8\D
M@)F/]%M$)E`N.2>&^Q$$)2A@`B``O(\L`*./```BCC``8A1$`+^/0`"TCSP`
MLX\X`+*/-`"QCS``L(\(`.`#2`"])R4H8`()^"`#)2```O'_0!0@`+R/!(&9
MCPGX(`,E(&`")2```B``O(\$@9F/"?@@`R6@0``@`+R/(1""`B2!F8\)^"`#
M`@!$)/__!B0@`+R/)2!``"6@0``8`+"O`0`%)!``LZ\D@(*/)("'CX"`F8\4
M6T(D&%OG)`GX(`,4`**O]%M$)B``O(\D@)F/4"XY)U3[$00E*(`"SO\`$"``
MO(]@@9F/"?@@`P`````"`!P\&-^<)R'@F0,0@+TG>(&#C___`CS<?[6O):B`
M`-A_M*]0@00TS'^QK^1^123(?["O['^_K^A_OJ_D?[>OX'^VK]1_LZ_0?[*O
M6/Z])R2`D8\@`*8G)("4CR@`O*\@`*<G(2"&`#@`HZ\``&:,4($#-"$0@@`D
M@(2/(1AG``1<,28A*&4`)("#C[1;D"0D@(2/_"N4)O!^0*P47&,D`']0K#P`
MI*_X6H0DZ'Y#K"7(@`(D@(./%']`K/1^4:R46F,D_'Y`K.Q^0ZQ,@0,T(1AG
M````9JPD@(./N%MC)`1_0ZPD@(./'%QC)`A_0ZPD@(./_%IC)`Q_0ZPD@(./
M)%QC)!!_0ZPD@(./*%QC)'3Z$03X?D.L!`!`$"@`O(\``$.`I0%@%#R`F8]`
M@)F/1O\1!``````H`+R/80%`$"600``$@9F/"?@@`R4@0`(H`+R/0!`"`"2!
MF8\)^"`#`0!$)```0X(EB$``$0!@$"@`O(\D@):/)9@@`C1<UB8``$*2`0!2
M)H"`F8___P8D`0`%)"4@8`(0`**O"?@@`R4XP`("`',F``!"@O3_0!0H`+R/
M__\6/"2`DX\@`*,G4($"-"4@``(A$$,``'_0)N1^UB8A@%``4($"-$PS<R8A
M$$,`!0``$"&P5@`$`!`F```$CA0`@!``````)<B``CCZ$00E*,`"*`"\C_?_
M0!`ED$````!"@/3_0!`ER&`"!/P1!"4@0`+P_T`0*`"\CX"!F8\)^"`#)2!`
M`B@`O(\A`$`4)8!``/__%CPD@)*/4($"-"``HR?H?M,F(1!#`"6X``!,,U(F
M(9A3`%"!`C0@`*0G@!@7`"$01``A$%8`(1!#`.A^4(P.```2`````````H(+
M`$`0)<A``N7[$00E(``"`0#W)F,`0!0H`+R/@!`7`"$08@(``%",]/\`%@``
M```E@```!(&9CPGX(`,E(``")2`@`B@`O(\$@9F/"?@@`R6P0``H`+R/(;#"
M`@0$UB8D@9F/"?@@`R4@P`+__P8D*`"\CR4@0``ED$``'`"QKP$`!200`+"O
M)("3CR2`@H\D@(>/@("9CR!;<R9(7$(D/%SG)!0`LZ\)^"`#&`"BK\`!!20H
M`+R/Z("9CPGX(`,E($`"__\#)`@`0Q0H`+R/X("9CPGX(`,`````$0`#)```
M0HP#`4,4*`"\CR``HR>0@)F/__\1/%"!`C08?R8F(1!#``,`!"0A,$8`"?@@
M`R4H0`(H`+R/*@!`$"6`0`",@8*/`0`%)"2`AH\EB```J("9CP``IXX``$2,
MC%S&)`GX(`,0`+*O*`"\CR``HR=,@0(T(1!#`#@`HX\``$2,)1`@`@``8XR7
M`H,48(&9CZ@!O2?L?[^/Z'^^C^1_MX_@?[:/W'^UC]A_M(_4?[./T'^RC\Q_
ML8_(?["/"`#@`_!_O2>`@9F/"?@@`R4@``(H`+R/B/]`$"6`0`">_P`0!(&9
MCR``HR=0@0(T(1!#``!``R0AN%$`,'_BC@#P0C#0_T,4C(&"CUR!F8\)^"`#
M.'_^CLK_PA<H`+R/,'_BCL`!`R3_`4(PQO]#%(R!@H\D@9F/"?@@`R4@P`+D
M?B4F*`"\CR``HR<EB$``4($"-"7(@`(D@(2/(1!#`"$H10"#^1$$X%R$),(`
M0!`H`+R/@(&9CR4@0``)^"`#``"TCB@`O(\E((`"1("9CU7\$00E*$``*`"\
MC[8`0!`EH$``!(&9CPGX(`,E((`");!```0`0BP0`$`4*`"\CR2`A8_\_\0F
MH(&9CR$@A`()^"`#Z%RE)`@`0!0H`+R/!``")/L!PA(AL)8"+P`")/O_PX+W
M`6(0`````$B`F8\*_A$$``````@`0!0H`+R/_("9CR4H```)^"`#)2"``B@`
MO(^6`$`40`"BKR2`A8___Q8D)("$CQ$`%R0D@(*/\%NE)&A;A"10+EDDWOD1
M!"7P(`,H`+R/,(&9CPGX(`,`````__\&)"@`O(\!``4D)2`@`A@`HJ\4`+.O
M$`"RKR2`E(\D@(>/@("9C\A=E"8(7><D"?@@`QP`M*\H`+R/)("5CQ<``!`8
M7;4FX("9CPGX(`,```````!"C!<`5Q0H`+R/,(&9CPGX(`,!`!`F__\&)"@`
MO(\!``4D(`"TKR4XH`(<`+"O)2`@`A@`HJ\4`+.O@("9CPGX(`,0`+*O*`"\
MC^B`F8_``04D"?@@`R4@(`+E_U80*`"\CX2!F8\)^"`#)2!``B4H(`(\`**/
M)<C``PGX(`/X6D0D*`"\CSR`F8_Z_1$$)2`@`DC_`!`H`+R/__\3/%"!`C0@
M`*,GY'YF)B$00P`EN```]'YV)B'P1@`E("`"4($"-"``HR<A$$,`#P"`$"&(
M5@`ER(`"^/@1!"4HP`,!`/<F!`!`$"@`O(\``$.`#@!@%("!F8^`$!<`(1`B
M`@``1(ST_X`4)<B``B2!F8\)^"`##0`$)"@`O(\EB$``)("2CXG^`!`,7%(F
M"?@@`R4@0``H`+R/>/Y`%"600``@`*0G4($"-(`8%P`A$$0`(1!3`"$00P#9
M_P`0]'Y$C(R!@X\!``4D)("&CR6(``"H@)F/``"GC@``9(Q07,8D%`"BKPGX
M(`,0`+*O"O\`$"@`O(\E($``M_T1!#0`HJ\H`+R/-`"BCX"!F8\)^"`#)2!`
M`"@`O(___@`0)8A``$K_`!```+2.-(&9CP(`%B3N_P8D__\')!``MJ\E($``
M"?@@`R6H0``H`+R/(`"C)___$#Q0@0(T_'\4)B$00P"8@9F/!@`&)"&@5``E
M(*`""?@@`R4H@`)0@0(T(`"C)R$00P`A@%``_'\"D@4`0!0H`+R/_7\"DD,`
M`R16`4,000`#)#2!F8\E,```0`"DCR4X```)^"`#$`"@KR``I"=0@0,T*`"\
MC___`CPA&&0`_']*)!A_220A$&(`4($#-"4H```A&&0`D']`K!Q_1:PE*```
M(:AJ`%"!`S0D?T6L)2@``$P`M:\A&&0`16<$/"Q_1:PAL&D`)("#CP$CA#08
M?T2LS>\$/"4H``")JX0T(']$K+J8!#P@&6,D-']%K/[<A#0H?T2L,A`$/"4H
M```T`*.O=E2$-#!_1*S2PP0\.`##)CQ_1:SPX80T)2@``#A_1*PE(```1`"C
MKR7P0`!$?T6L0']$K$A_1*Q,?T6LF(&9CP"`!C1``*2/"?@@`R4HH`(H`+R/
M8P!`&"6X0`!`?\*/P#`7`$1_PX_#+Q<`2'_$CR$PP@`$`&`43'_'CRL0P@`&
M`$`0P%@%``$`@B0K($0`(3B'`"4@0`#`6`4`D'_"CT(?%P!`?\:O0B\%`$1_
MP*\E&&,!(2!D`"$HIP`K&(,`2'_$KR$890!$`$`03'_#KT``$"1$`*./?(&9
MCR.@`@),`*6/(2!B`"H0EP(*H.(""?@@`R4P@`*0?\*/*`"\CR$0@@+-_U`4
MD'_"KS0`N8\E(,`""?@@`R.X]`),`**/*`"\CR&`5`!``.,J(@!@%"6@``+`
M__<F@A$7``$`5"1(`**O@*$4`"&@%`)0?\,G0``+)B40``(#`$>($`!C)`<`
M1H@+`$6(#P!$B```1Y@$`$:8"`!%F`P`1)@0`$(D\/]GK/3_9JSX_V6L\O]+
M%/S_9*PT`+F/)2#``@GX(`,E@$``Z?^0%B@`O(](`**/@($"`".X\`(<@9F/
M2``')$0`I(\E,.`""?@@`R4H@`(H`+R/F?\`$)!_UZ_2_P`0)8"@`HR`F8\)
M^"`#0`"DCR``HR=0@0(T*`"\CR``I2<A$$,`__\#/"$00P`E,&``0']4C$A_
M5XQ0@0(TP"B$?B$010"@H!1\(1!$``$`A"0A$&(`H+@7?(#_!20Y`(,H`J0T
M`%!_1:"(`&`4`KPW`"``HR?L@)F/4($"-!A_U20A$$,`0``&)"&H50`C,,0`
M.`"P)B4H```)^"`#(2`$`C0`N8\)^"`#)2"@`C@`H*X\`*"N0`"@KD0`H*Y(
M`*"N3`"@KE``H*Y4`*"N6`"@KEP`H*Y@`*"N9`"@KF@`H*YL`*"N(`"C)S0`
MN8]0@0(T__\5/"$00P`8?Z0F(8!5`%"!`C0A$$,`B'\7KHQ_%*[0?[0F"?@@
M`R$@1``@`*0G4($#-"@`O(\8?P*.(1AD`"!_!HXH?P6.(:AU`"2`EH]0@0,T
MH#@"?"$89``P?P2.H#`&?"&@=``X?P..H"@%?*`@!'R@&`-\`CPG``(T)@`"
M+"4`O'\'K@(D)`#`?P:N`APC`,1_!:Z]?[<FR'\$K@(6`@#,?P.N*`"5)@,`
M`!`T7-8F``#BD@$`]R:`@)F/)2"``O__!B00`**O`0`%)`(`E"8)^"`#)3C`
M`O7_M!8H`+R/(`"E)R2`AX]0@00T@("9C___`CP4`+.O(2"%`!``LJ_0?T,D
M(1""`%"!!#3__P8D(2"%`/A<YR0A&(,`)("$CP$`!208`*.OR%V$)!P`I*\E
M("`"^']`H`GX(`,`````*`"\CR2`@H]0+D(D4_X`$"7P0``$`+6."/Z@$@2!
MF8\)^"`#)2"@`@0`0RP#_F`4*`"\CR2`A8_\_T(DH(&9CR$@H@()^"`#\%RE
M)"@`O(_Z_0`0"J"B`B``HR?L@)F/4($"-#@`!B0A$$,`__\#/",PQ``A$$,`
M)2@``%!_0B0)^"`#(2!$`(K_`!`@`*,G_G\$DJK^@Q0T@9F/_W\#DJC^8A0E
M,```<`&CDT@``B2D_F(4<0&CDT4``B2A_F(4__\')$``L(\T@9F/QO\&)!``
MMJ\)^"`#)2```BD`!B0H`+R/)2B``IB!F8\)^"`#)2```O__!B0H`+R/`0`%
M)"4@(`(8`+2O%`"SKQ``LJ\D@(*/)("'CX"`F8_(74(D^%SG)+3_`!`<`**O
M"?@@`P`````"`!P\M-"<)R'@F0.@_[TG>(&"CY2`F8\\`+&O7`"_KQ``O*]`
M`+*O,`"R)S@`L*]8`+ZO5`"WKU``MJ],`+6O2`"TKT0`LZ\L`**O6(&1CP``
M0HPD`+*O-`"BKPGX(`,``"2.$`"\CR6`0`"4@)F/"?@@`P``)(XE*$`"$`"\
MCV@``Y(D@(:/)("$CVD`0Z#\*]DD3%N$)/GV$00H`+FO!0!`$!``O(\``$2`
M,0`#)/X`@Q``````3("9C^KZ$00`````$`"\CY2`F8\)^"`#```DC@L`!R00
M`+R/`0`&)"4@0``D@(6/((&9CPGX(`,L7:4DZP!`$!``O(\H@)./$`!$C```
M/H[XL6*.`@!"*$,`0!08`)2,(``5/"B`EX\ED````0`0)``$M28,```0``06
M)*"!F8\E("`!"?@@`Q``Q8P0`+R/,@!`%/BQ9(X!`!`F*A`$`BX`0!`!`%(F
ME("9CPGX(`,E(,`#)3@``!``O(\E,$`")2B``KR`F8\)^"`#)2!``!``O(_,
M`$`0)4!`````1HR`(!``]+'EC@``/HX(`,*,(2"D`"0050#@_U80``")C)2`
MF8\E(,`#'`"IKPGX(`,@`*BO`@`')!``O(\E,```(`"HCR4@0`!`@9F/"?@@
M`P``!8T0`+R/)2A``!P`J8\``#Z.H(&9CPGX(`,E("`!$`"\C]#_0!#XL62.
M__^")(,`4A`"`(0HE("9CPGX(`,E(,`#`P`')!``O(\!``8D)2!``"2`A8\@
M@9F/"?@@`S1=I200`+R/$@!`$"6`0`"4@)F/"?@@`P``)(X0`+R/)2!``!``
M`XXD@(:/1(&9CP``98P)^"`#.%W&)!```HX``$*,"`!"C(`%0GR=`$`4$`"\
MCY2`F8\)^"`#```DC@,`!R00`+R/`0`&)"4@0``D@(6/((&9CPGX(`-`7:4D
M$`"\CQ4`0!`E@$``)("$CR@`N8\D`*6/"?@@`P1;A"00`+R/)9!`````)(YX
M`$`0E("9CPGX(`,`````)3!``A``O(\E($``$``#CD2!F8\)^"`#``!EC!``
MO(^4@)F/*("2CPGX(`,``"2.$`"\CR6`0`"4@)F/"?@@`P``)(X!``8D$`"\
MCR4@0``D@(6/^("9CPGX(`-$7:4D)2```A``O(\E*$``)("&CT2!F8\)^"`#
M7%W&)!``O(^4@)F/"?@@`P``)(X0`+R/)`"ECR@`N8]I`$"@)("$CPGX(`/X
M6H0D$`"\CR6`0``O`$`0_+%"KNB`F8_``04D"?@@`R4@``(1``,D!0!#$!``
MO(\!`$,D`@!C+%@`8!`E.$``+`"BCS0`HX\``$*,4`!B%%P`OX]8`+Z/5`"W
MCU``MH],`+6/2`"TCT0`LX]``+*//`"QCS@`L(\(`.`#8`"])W[_@!24@)F/
M`0`0))2`F8\E(,`#"?@@`P$`$"8E*(`"$`"\CW2!F8\)^"`#)2!``/BQ8HX0
M`+R/*A`"`O/_0!0``#Z.;?\`$)2`F8\H@(*/4("9CT?[$03TL42,$`"\CR6`
M0`#+_T`4_+%"KB2`A(_T@)F/"?@@`V1=A"1>_P`0```^C@$`0H`%_T`03("9
MCP#_`!``````^+%DCO__@B15_U(4```^CM7_`!`"`(0H"?@@`P`````0`+R/
M$``#CBB`@H\D@)F/``!DC/2Q0HP$-#DGXO<1!```18R'_P`0$`"\CY2`F8\)
M^"`#```DCA``O(\E($``$``#CM2`F8\)^"`#``!EC%K_`!`0`+R/8(&9CPGX
M(`,`````*(""CR2`A(\E,``"]("9C_2Q0HR(780D"?@@`P``18P"`!P\4,N<
M)R'@F0/8_[TG5("9CQ``O*\@`+&O'`"PKR0`OZ]6^1$$)8B`````0X`E@$``
M!P!@$!``O(\!`$(D+P!C.`J`0P```$.`_/]@%`$`0B1(@)F/7OH1!``````-
M`$`0$`"\CPP`(!(D`+^/```B@@D`0!`$``8D)("%CZ"`F8\E(``""?@@`TA<
MI20&`$`0$`"\CR0`OX\@`+&/'`"PCP@`X`,H`+TG)("9CR4@(`(D`+^/(`"Q
MCQP`L(\D,3DGW_8`$"@`O2<``````@`</(#*G"<AX)D#:(""CSB!F8\(`"`#
M``!'C``````"`!P\8,J<)R'@F0/(_[TG;("9CQ``O*\P`+6O):C``"P`M*\E
MH*``*`"SKR68@``D`+*O'`"PKS0`OZ^8[Q$$(`"QKQ``O(]P@)"/=("2CR.0
M4`*#D!(`"0!`$B6(`````!F.`0`Q)B4PH`(E*(`""?@@`R4@8`+Y_U$6!``0
M)C0`OX\P`+6/+`"TCR@`LX\D`+*/(`"QCQP`L(\(`.`#.`"])P@`X`,`````
M`````!"`F8\E>.`#"?@@`VP`&"00@)F/)7C@`PGX(`-K`!@D$("9CR5XX`,)
M^"`#:0`8)!"`F8\E>.`#"?@@`V<`&"00@)F/)7C@`PGX(`-E`!@D$("9CR5X
MX`,)^"`#9``8)!"`F8\E>.`#"?@@`V,`&"00@)F/)7C@`PGX(`-B`!@D$("9
MCR5XX`,)^"`#8``8)!"`F8\E>.`#"?@@`UX`&"00@)F/)7C@`PGX(`-=`!@D
M$("9CR5XX`,)^"`#7``8)!"`F8\E>.`#"?@@`UL`&"00@)F/)7C@`PGX(`-:
M`!@D$("9CR5XX`,)^"`#6``8)!"`F8\E>.`#"?@@`U<`&"00@)F/)7C@`PGX
M(`-5`!@D$("9CR5XX`,)^"`#5``8)!"`F8\E>.`#"?@@`U,`&"00@)F/)7C@
M`PGX(`-2`!@D$("9CR5XX`,)^"`#40`8)!"`F8\E>.`#"?@@`U``&"00@)F/
M)7C@`PGX(`-/`!@D$("9CR5XX`,)^"`#3@`8)!"`F8\E>.`#"?@@`TT`&"00
M@)F/)7C@`PGX(`-,`!@D$("9CR5XX`,)^"`#2P`8)!"`F8\E>.`#"?@@`TH`
M&"00@)F/)7C@`PGX(`-(`!@D$("9CR5XX`,)^"`#1@`8)!"`F8\E>.`#"?@@
M`T4`&"00@)F/)7C@`PGX(`-$`!@D$("9CR5XX`,)^"`#0P`8)!"`F8\E>.`#
M"?@@`T(`&"00@)F/)7C@`PGX(`-!`!@D$("9CR5XX`,)^"`#0``8)!"`F8\E
M>.`#"?@@`S\`&"00@)F/)7C@`PGX(`,^`!@D$("9CR5XX`,)^"`#/0`8)!"`
MF8\E>.`#"?@@`SL`&"00@)F/)7C@`PGX(`,Z`!@D$("9CR5XX`,)^"`#.0`8
M)!"`F8\E>.`#"?@@`S@`&"00@)F/)7C@`PGX(`,W`!@D$("9CR5XX`,)^"`#
M-@`8)!"`F8\E>.`#"?@@`S4`&"00@)F/)7C@`PGX(`,T`!@D$("9CR5XX`,)
M^"`#,P`8)!"`F8\E>.`#"?@@`S(`&"00@)F/)7C@`PGX(`,P`!@D$("9CR5X
MX`,)^"`#+P`8)!"`F8\E>.`#"?@@`RX`&"00@)F/)7C@`PGX(`,M`!@D$("9
MCR5XX`,)^"`#*P`8)!"`F8\E>.`#"?@@`RD`&"00@)F/)7C@`PGX(`,H`!@D
M$("9CR5XX`,)^"`#)P`8)!"`F8\E>.`#"?@@`R8`&"00@)F/)7C@`PGX(`,E
M`!@D$("9CR5XX`,)^"`#)``8)!"`F8\E>.`#"?@@`R,`&"0`````````````
M`````````@`</-#%G"<AX)D#X/^])Q``O*\<`+^O'`"_CP@`X`,@`+TG````
M`````````````0`"`"X````N+@``)7,O)7,````O<')O8R]S96QF+V5X90``
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`````!005)?4%)/1TY!
M344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$52
M3#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!
M3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT`
M`#$```!,1%],24)205)97U!!5$@`55-%4@````!365-414T``"]T;7``````
M5$5-4$1)4@!435``55-%4DY!344`````)3`R>``````E<R5S)7,E<P````!P
M87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````"5S)7-C
M86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``
M``!!4D=6`````!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/
M3@`````Q+C`T-P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]
M("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E
M("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE
M;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?
M<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@
M)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(
M*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S
M970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]
M("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T
M+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=
M.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q
M6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A
M9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN
M(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@
M)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N
M;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(
M+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M
M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U
M9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E
M7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D
M9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L
M;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E
M>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E
M>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L
M;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@
M;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM
M>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F
M+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92![
M"B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C
M<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F
M:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O
M('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE
M>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*
M?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA
M;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE
M;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC
M<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L
M("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2([
M"F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*
M=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES
M="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE
M(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@
M>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N
M;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID
M96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5]
M.R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M
M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@
M("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*
M=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G
M+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@
M/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO
M=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@
M97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2![
M"G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2![
M"B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G
M<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<[
M"GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D
M,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8
M.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2![
M"B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R
M(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H
M*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A
M<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`]
M(%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@
M;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES
M(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B
M.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/
M3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D
M(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<
M)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R
M(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA
M<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L
M(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@
M(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!
M4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC
M*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L
M96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@
M/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM
M>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE
M(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI
M7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L
M<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@
M)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A
M8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*
M<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\
M)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO
M9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R
M:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I
M;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]
M"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E
M('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM
M;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]
M"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD[
M"B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D
M0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*
M<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A
M;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE
M=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@
M?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP
M('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O
M<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)
M4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T
M;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D
M<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M
M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I
M9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]
M("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*
M)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#
M;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY
M("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R
M96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2![
M"G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U
M9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C
M:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI6
M15)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@
M)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G
M;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O
M<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C
M='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.
M5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@
M/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S
M<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N
M)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG
M="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F
M:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M
M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA
M;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64[
M"GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]0
M4D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*
M)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%
M3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*
M<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I
M<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B
M+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I
M9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII
M9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*
M?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W
M*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'
M0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G
M+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0
M?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S
M("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R
M*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?
M0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH```````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(`````!P97)L>'-I+F,`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````&0``E!@```````````````````````#_____````````````````U%T`
M````````````````````````````````````````````````@+`4``#050``
M=%8```````````(````!`&PU``!\3P``2#8``+@_``!D/P``<#<``+0^``#D
M.P``&$$``&`Z``"P50``(*`!`.!4```TH`$`V*$!`'`4``#XGP$`_)\!````
M````````0%H``#!:```@6@``$%H```!:``#P60``X%D```````#060``````
M`,!9``"P60``H%D``)!9````````@%D``'!9``!@60``4%D``$!9```P60``
M(%D``!!9````60``\%@```````#@6```T%@``,!8``"P6```H%@``)!8``"`
M6```<%@``&!8``!06````````$!8````````,%@``"!8```06````%@``/!7
M``#@5P``T%<``,!7``"P5P``H%<``)!7``"`5P```````'!7``!@5P``````
M`%!7``!`5P``,%<``"!7```05P````````!7````````\%8``.!6``#05@``
MP%8```````"P5@```````*!6````````D%8``(!6``#8H0$`1T-#.B`H1&5B
M:6%N(#@N,BXP+3DI(#@N,BXP`$=#0SH@*$1E8FEA;B`W+C,N,"TR.2D@-RXS
M+C``````(!D``````X#\____``````````"P`@``'0```!\```#\*P````!_
M@/S___\``````````#@````=````'P```'`M`````!^`_/___P``````````
M.````!T````?````4"X`````_X#\____``````````!(````'0```!\````D
M,0````#_P/S___\``````````/@````=````'P```$PS``````.`_/___P``
M````````T````!T````?````!#0`````/X#\____``````````!`$```'0``
M`!\```!L-0``````@/S___\``````````"`````=````'P```,`U``````&`
M_/___P``````````*````!T````?````2#8`````!X#\____``````````!`
M(```'0```!\```!8-P`````````````````````````````=````'P```'`W
M`````/_`_/___P``````````"!$``!T````?````-#H`````````````````
M````````````'0```!\```!@.@`````#@/S___\``````````"@````=````
M'P```.0[`````'^`_/___P``````````:````!T````?````M#X``````X#\
M____```````````P````'0```!\```!D/P``````@/S___\``````````"``
M```=````'P```+@_`````!^`_/___P``````````2````!T````?````&$$`
M````_\#\____``````````"8@0``'0```!\```!\3P````#_P/S___\`````
M`````&`````=````'P```.!4``````.`_/___P``````````*````!T````?
M````L!0`````/X#\____``````````!0````'0```!\```"P50``````````
M```````````````````=````'P```-!5`````#^`_/___P``````````.```
M`!T````?````=%8`````````````````````````````'0```!\```!!#P``
M`&=N=0`!!P````0%`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`
M+DU)4%,N86)I9FQA9W,`+G)E9VEN9F\`+FYO=&4N9VYU+F)U:6QD+6ED`"YD
M>6YA;6EC`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;"YD>6X`+FEN:70`+G1E>'0`+DU)4%,N<W1U8G,`
M+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1A=&$`+G)L9%]M87``+F=O=``N<V1A=&$`+F)S<P`N8V]M;65N=``N
M<&1R`"YG;G4N871T<FEB=71E<P`N;61E8G5G+F%B:3,R````````````````
M```````````````````````````````````````+`````0````(```"4`0``
ME`$```T```````````````$`````````$P````<````"````I`$``*0!```@
M```````````````$`````````"$````J``!P`@```,@!``#(`0``&```````
M````````"````!@````P````!@``<`(```#@`0``X`$``!@`````````````
M``0````8````.0````<````"````^`$``/@!```D```````````````$````
M`````$P````&`````@```!P"```<`@``4`$```D`````````!`````@```!5
M````!0````(```!L`P``;`,``$`#```(``````````0````$````6P````L`
M```"````K`8``*P&``#0!@``"0````(````$````$````&,````#`````@``
M`'P-``!\#0``004``````````````0````````!K````____;P(```"^$@``
MOA(``-H````(``````````(````"````>````/[__V\"````F!,``)@3``"P
M````"0````,````$`````````(<````)`````@```$@4``!(%```*`````@`
M````````!`````@```"0`````0````8```!P%```<!0``#P`````````````
M``0`````````E@````$````&````L!0``+`4``#000`````````````0````
M`````)P````!````!@```(!6``"`5@``X`,`````````````!`````````"H
M`````0````8```!@6@``8%H``"0```````````````0`````````K@````$`
M```"````D%H``)!:``"P/P`````````````0`````````+8````!`````@``
M`$":``!`F@``!```````````````!`````````#`````#@````,```#XGP$`
M^)\```0```````````````0````$````S`````\````#````_)\!`/R?```$
M```````````````$````!````-@````!`````P````"@`0``H```,```````
M````````$`````````#>`````0````,````PH`$`,*````0`````````````
M``0`````````YP````$````#```00*`!`$"@``"8`0`````````````0````
M!````.P````!`````P``$-BA`0#8H0``!```````````````!`````````#S
M````"`````,```#@H0$`W*$``#`0`````````````!``````````^`````$`
M```P`````````-RA```Y```````````````!`````0````$!```!````````
M```````8H@``(`,`````````````!``````````&`0``]?__;P``````````
M.*4``!````````````````$`````````%@$```$``````````````$BE````
M```````````````!``````````$````#``````````````!(I0``)`$`````
.`````````0``````````
